# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/ai/vision/v1/classification.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/ai/vision/v1/classification.proto',
  package='yandex.cloud.ai.vision.v1',
  syntax='proto3',
  serialized_options=b'\n\035yandex.cloud.api.ai.vision.v1ZDgithub.com/yandex-cloud/go-genproto/yandex/cloud/ai/vision/v1;vision',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n.yandex/cloud/ai/vision/v1/classification.proto\x12\x19yandex.cloud.ai.vision.v1\"J\n\x0f\x43lassAnnotation\x12\x37\n\nproperties\x18\x01 \x03(\x0b\x32#.yandex.cloud.ai.vision.v1.Property\"-\n\x08Property\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0bprobability\x18\x02 \x01(\x01\x42\x65\n\x1dyandex.cloud.api.ai.vision.v1ZDgithub.com/yandex-cloud/go-genproto/yandex/cloud/ai/vision/v1;visionb\x06proto3'
)




_CLASSANNOTATION = _descriptor.Descriptor(
  name='ClassAnnotation',
  full_name='yandex.cloud.ai.vision.v1.ClassAnnotation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='properties', full_name='yandex.cloud.ai.vision.v1.ClassAnnotation.properties', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=77,
  serialized_end=151,
)


_PROPERTY = _descriptor.Descriptor(
  name='Property',
  full_name='yandex.cloud.ai.vision.v1.Property',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.ai.vision.v1.Property.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='probability', full_name='yandex.cloud.ai.vision.v1.Property.probability', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=153,
  serialized_end=198,
)

_CLASSANNOTATION.fields_by_name['properties'].message_type = _PROPERTY
DESCRIPTOR.message_types_by_name['ClassAnnotation'] = _CLASSANNOTATION
DESCRIPTOR.message_types_by_name['Property'] = _PROPERTY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ClassAnnotation = _reflection.GeneratedProtocolMessageType('ClassAnnotation', (_message.Message,), {
  'DESCRIPTOR' : _CLASSANNOTATION,
  '__module__' : 'yandex.cloud.ai.vision.v1.classification_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.ai.vision.v1.ClassAnnotation)
  })
_sym_db.RegisterMessage(ClassAnnotation)

Property = _reflection.GeneratedProtocolMessageType('Property', (_message.Message,), {
  'DESCRIPTOR' : _PROPERTY,
  '__module__' : 'yandex.cloud.ai.vision.v1.classification_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.ai.vision.v1.Property)
  })
_sym_db.RegisterMessage(Property)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
