# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/logging/v1/log_group_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.access import access_pb2 as yandex_dot_cloud_dot_access_dot_access__pb2
from yandex.cloud.logging.v1 import log_group_pb2 as yandex_dot_cloud_dot_logging_dot_v1_dot_log__group__pb2
from yandex.cloud.logging.v1 import log_resource_pb2 as yandex_dot_cloud_dot_logging_dot_v1_dot_log__resource__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/logging/v1/log_group_service.proto',
  package='yandex.cloud.logging.v1',
  syntax='proto3',
  serialized_options=b'\n\033yandex.cloud.api.logging.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/logging/v1;logging',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n/yandex/cloud/logging/v1/log_group_service.proto\x12\x17yandex.cloud.logging.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x1egoogle/protobuf/duration.proto\x1a google/protobuf/field_mask.proto\x1a yandex/cloud/api/operation.proto\x1a yandex/cloud/access/access.proto\x1a\'yandex/cloud/logging/v1/log_group.proto\x1a*yandex/cloud/logging/v1/log_resource.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\"8\n\x12GetLogGroupRequest\x12\"\n\x0clog_group_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=64\"=\n\x17GetLogGroupStatsRequest\x12\"\n\x0clog_group_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=64\"\x85\x01\n\x14ListLogGroupsRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=64\x12\x11\n\tpage_size\x18\x02 \x01(\x03\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"c\n\x15ListLogGroupsResponse\x12\x31\n\x06groups\x18\x01 \x03(\x0b\x32!.yandex.cloud.logging.v1.LogGroup\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xa0\x03\n\x15\x43reateLogGroupRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=64\x12\x34\n\x04name\x18\x02 \x01(\tB&\xf2\xc7\x31\"([a-z]([-a-z0-9]{1,61}[a-z0-9])?)?\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x8b\x01\n\x06labels\x18\x04 \x03(\x0b\x32:.yandex.cloud.logging.v1.CreateLogGroupRequest.LabelsEntryB?\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xf2\xc7\x31\x0b[-_0-9a-z]*\xb2\xc8\x31\x06\x1a\x04\x31-63\xb2\xc8\x31\x12\x12\x10[a-z][-_0-9a-z]*\x12\x33\n\x10retention_period\x18\x05 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x1e\n\x0b\x64\x61ta_stream\x18\x06 \x01(\tB\t\x8a\xc8\x31\x05<=512\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\".\n\x16\x43reateLogGroupMetadata\x12\x14\n\x0clog_group_id\x18\x01 \x01(\t\"\xd4\x03\n\x15UpdateLogGroupRequest\x12\"\n\x0clog_group_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=64\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x34\n\x04name\x18\x03 \x01(\tB&\xf2\xc7\x31\"([a-z]([-a-z0-9]{1,61}[a-z0-9])?)?\x12\x1e\n\x0b\x64\x65scription\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x8b\x01\n\x06labels\x18\x05 \x03(\x0b\x32:.yandex.cloud.logging.v1.UpdateLogGroupRequest.LabelsEntryB?\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xf2\xc7\x31\x0b[-_0-9a-z]*\xb2\xc8\x31\x06\x1a\x04\x31-63\xb2\xc8\x31\x12\x12\x10[a-z][-_0-9a-z]*\x12\x33\n\x10retention_period\x18\x06 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x1e\n\x0b\x64\x61ta_stream\x18\x07 \x01(\tB\t\x8a\xc8\x31\x05<=512\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\".\n\x16UpdateLogGroupMetadata\x12\x14\n\x0clog_group_id\x18\x01 \x01(\t\";\n\x15\x44\x65leteLogGroupRequest\x12\"\n\x0clog_group_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=64\".\n\x16\x44\x65leteLogGroupMetadata\x12\x14\n\x0clog_group_id\x18\x01 \x01(\t\"S\n\x14ListResourcesRequest\x12\"\n\x0clog_group_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=64\x12\x17\n\x04type\x18\x02 \x01(\tB\t\x8a\xc8\x31\x05<=256\"U\n\x15ListResourcesResponse\x12<\n\tresources\x18\x01 \x03(\x0b\x32).yandex.cloud.logging.v1.LogGroupResource\"\x95\x01\n\x15ListOperationsRequest\x12\"\n\x0clog_group_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=64\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"h\n\x16ListOperationsResponse\x12\x35\n\noperations\x18\x01 \x03(\x0b\x32!.yandex.cloud.operation.Operation\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"P\n\x18GetLogGroupStatsResponse\x12\x14\n\x0clog_group_id\x18\x01 \x01(\t\x12\r\n\x05\x62ytes\x18\x02 \x01(\x03\x12\x0f\n\x07records\x18\x03 \x01(\x03\x32\xc8\x0f\n\x0fLogGroupService\x12\x83\x01\n\x03Get\x12+.yandex.cloud.logging.v1.GetLogGroupRequest\x1a!.yandex.cloud.logging.v1.LogGroup\",\x82\xd3\xe4\x93\x02&\x12$/logging/v1/logGroups/{log_group_id}\x12\xa0\x01\n\x05Stats\x12\x30.yandex.cloud.logging.v1.GetLogGroupStatsRequest\x1a\x31.yandex.cloud.logging.v1.GetLogGroupStatsResponse\"2\x82\xd3\xe4\x93\x02,\x12*/logging/v1/logGroups/{log_group_id}/stats\x12\x84\x01\n\x04List\x12-.yandex.cloud.logging.v1.ListLogGroupsRequest\x1a..yandex.cloud.logging.v1.ListLogGroupsResponse\"\x1d\x82\xd3\xe4\x93\x02\x17\x12\x15/logging/v1/logGroups\x12\xa3\x01\n\x06\x43reate\x12..yandex.cloud.logging.v1.CreateLogGroupRequest\x1a!.yandex.cloud.operation.Operation\"F\x82\xd3\xe4\x93\x02\x1a\"\x15/logging/v1/logGroups:\x01*\xb2\xd2*\"\n\x16\x43reateLogGroupMetadata\x12\x08LogGroup\x12\xb2\x01\n\x06Update\x12..yandex.cloud.logging.v1.UpdateLogGroupRequest\x1a!.yandex.cloud.operation.Operation\"U\x82\xd3\xe4\x93\x02)2$/logging/v1/logGroups/{log_group_id}:\x01*\xb2\xd2*\"\n\x16UpdateLogGroupMetadata\x12\x08LogGroup\x12\xbc\x01\n\x06\x44\x65lete\x12..yandex.cloud.logging.v1.DeleteLogGroupRequest\x1a!.yandex.cloud.operation.Operation\"_\x82\xd3\xe4\x93\x02&*$/logging/v1/logGroups/{log_group_id}\xb2\xd2*/\n\x16\x44\x65leteLogGroupMetadata\x12\x15google.protobuf.Empty\x12\xaa\x01\n\rListResources\x12-.yandex.cloud.logging.v1.ListResourcesRequest\x1a..yandex.cloud.logging.v1.ListResourcesResponse\":\x82\xd3\xe4\x93\x02\x34\x12\x32/logging/v1/logGroups/{log_group_id}:listResources\x12\xaa\x01\n\x0eListOperations\x12..yandex.cloud.logging.v1.ListOperationsRequest\x1a/.yandex.cloud.logging.v1.ListOperationsResponse\"7\x82\xd3\xe4\x93\x02\x31\x12//logging/v1/logGroups/{log_group_id}/operations\x12\xb5\x01\n\x12ListAccessBindings\x12..yandex.cloud.access.ListAccessBindingsRequest\x1a/.yandex.cloud.access.ListAccessBindingsResponse\">\x82\xd3\xe4\x93\x02\x38\x12\x36/logging/v1/logGroups/{resource_id}:listAccessBindings\x12\xe4\x01\n\x11SetAccessBindings\x12-.yandex.cloud.access.SetAccessBindingsRequest\x1a!.yandex.cloud.operation.Operation\"}\x82\xd3\xe4\x93\x02:\"5/logging/v1/logGroups/{resource_id}:setAccessBindings:\x01*\xb2\xd2*9\n access.SetAccessBindingsMetadata\x12\x15google.protobuf.Empty\x12\xf1\x01\n\x14UpdateAccessBindings\x12\x30.yandex.cloud.access.UpdateAccessBindingsRequest\x1a!.yandex.cloud.operation.Operation\"\x83\x01\x82\xd3\xe4\x93\x02=28/logging/v1/logGroups/{resource_id}:updateAccessBindings:\x01*\xb2\xd2*<\n#access.UpdateAccessBindingsMetadata\x12\x15google.protobuf.EmptyBb\n\x1byandex.cloud.api.logging.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/logging/v1;loggingb\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,google_dot_protobuf_dot_field__mask__pb2.DESCRIPTOR,yandex_dot_cloud_dot_api_dot_operation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_access_dot_access__pb2.DESCRIPTOR,yandex_dot_cloud_dot_logging_dot_v1_dot_log__group__pb2.DESCRIPTOR,yandex_dot_cloud_dot_logging_dot_v1_dot_log__resource__pb2.DESCRIPTOR,yandex_dot_cloud_dot_operation_dot_operation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_validation__pb2.DESCRIPTOR,])




_GETLOGGROUPREQUEST = _descriptor.Descriptor(
  name='GetLogGroupRequest',
  full_name='yandex.cloud.logging.v1.GetLogGroupRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='log_group_id', full_name='yandex.cloud.logging.v1.GetLogGroupRequest.log_group_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=64', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=396,
  serialized_end=452,
)


_GETLOGGROUPSTATSREQUEST = _descriptor.Descriptor(
  name='GetLogGroupStatsRequest',
  full_name='yandex.cloud.logging.v1.GetLogGroupStatsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='log_group_id', full_name='yandex.cloud.logging.v1.GetLogGroupStatsRequest.log_group_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=64', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=454,
  serialized_end=515,
)


_LISTLOGGROUPSREQUEST = _descriptor.Descriptor(
  name='ListLogGroupsRequest',
  full_name='yandex.cloud.logging.v1.ListLogGroupsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='folder_id', full_name='yandex.cloud.logging.v1.ListLogGroupsRequest.folder_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=64', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='yandex.cloud.logging.v1.ListLogGroupsRequest.page_size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='yandex.cloud.logging.v1.ListLogGroupsRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filter', full_name='yandex.cloud.logging.v1.ListLogGroupsRequest.filter', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\006<=1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=518,
  serialized_end=651,
)


_LISTLOGGROUPSRESPONSE = _descriptor.Descriptor(
  name='ListLogGroupsResponse',
  full_name='yandex.cloud.logging.v1.ListLogGroupsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='groups', full_name='yandex.cloud.logging.v1.ListLogGroupsResponse.groups', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='yandex.cloud.logging.v1.ListLogGroupsResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=653,
  serialized_end=752,
)


_CREATELOGGROUPREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='yandex.cloud.logging.v1.CreateLogGroupRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.logging.v1.CreateLogGroupRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.logging.v1.CreateLogGroupRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1126,
  serialized_end=1171,
)

_CREATELOGGROUPREQUEST = _descriptor.Descriptor(
  name='CreateLogGroupRequest',
  full_name='yandex.cloud.logging.v1.CreateLogGroupRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='folder_id', full_name='yandex.cloud.logging.v1.CreateLogGroupRequest.folder_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=64', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.logging.v1.CreateLogGroupRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\3071\"([a-z]([-a-z0-9]{1,61}[a-z0-9])?)?', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.logging.v1.CreateLogGroupRequest.description', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=256', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='yandex.cloud.logging.v1.CreateLogGroupRequest.labels', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\3101\004<=64\212\3101\004<=63\362\3071\013[-_0-9a-z]*\262\3101\006\032\0041-63\262\3101\022\022\020[a-z][-_0-9a-z]*', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='retention_period', full_name='yandex.cloud.logging.v1.CreateLogGroupRequest.retention_period', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data_stream', full_name='yandex.cloud.logging.v1.CreateLogGroupRequest.data_stream', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=512', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CREATELOGGROUPREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=755,
  serialized_end=1171,
)


_CREATELOGGROUPMETADATA = _descriptor.Descriptor(
  name='CreateLogGroupMetadata',
  full_name='yandex.cloud.logging.v1.CreateLogGroupMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='log_group_id', full_name='yandex.cloud.logging.v1.CreateLogGroupMetadata.log_group_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1173,
  serialized_end=1219,
)


_UPDATELOGGROUPREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='yandex.cloud.logging.v1.UpdateLogGroupRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.logging.v1.UpdateLogGroupRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.logging.v1.UpdateLogGroupRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1126,
  serialized_end=1171,
)

_UPDATELOGGROUPREQUEST = _descriptor.Descriptor(
  name='UpdateLogGroupRequest',
  full_name='yandex.cloud.logging.v1.UpdateLogGroupRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='log_group_id', full_name='yandex.cloud.logging.v1.UpdateLogGroupRequest.log_group_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=64', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='update_mask', full_name='yandex.cloud.logging.v1.UpdateLogGroupRequest.update_mask', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.logging.v1.UpdateLogGroupRequest.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\3071\"([a-z]([-a-z0-9]{1,61}[a-z0-9])?)?', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.logging.v1.UpdateLogGroupRequest.description', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=256', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='yandex.cloud.logging.v1.UpdateLogGroupRequest.labels', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\3101\004<=64\212\3101\004<=63\362\3071\013[-_0-9a-z]*\262\3101\006\032\0041-63\262\3101\022\022\020[a-z][-_0-9a-z]*', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='retention_period', full_name='yandex.cloud.logging.v1.UpdateLogGroupRequest.retention_period', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data_stream', full_name='yandex.cloud.logging.v1.UpdateLogGroupRequest.data_stream', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=512', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_UPDATELOGGROUPREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1222,
  serialized_end=1690,
)


_UPDATELOGGROUPMETADATA = _descriptor.Descriptor(
  name='UpdateLogGroupMetadata',
  full_name='yandex.cloud.logging.v1.UpdateLogGroupMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='log_group_id', full_name='yandex.cloud.logging.v1.UpdateLogGroupMetadata.log_group_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1692,
  serialized_end=1738,
)


_DELETELOGGROUPREQUEST = _descriptor.Descriptor(
  name='DeleteLogGroupRequest',
  full_name='yandex.cloud.logging.v1.DeleteLogGroupRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='log_group_id', full_name='yandex.cloud.logging.v1.DeleteLogGroupRequest.log_group_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=64', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1740,
  serialized_end=1799,
)


_DELETELOGGROUPMETADATA = _descriptor.Descriptor(
  name='DeleteLogGroupMetadata',
  full_name='yandex.cloud.logging.v1.DeleteLogGroupMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='log_group_id', full_name='yandex.cloud.logging.v1.DeleteLogGroupMetadata.log_group_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1801,
  serialized_end=1847,
)


_LISTRESOURCESREQUEST = _descriptor.Descriptor(
  name='ListResourcesRequest',
  full_name='yandex.cloud.logging.v1.ListResourcesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='log_group_id', full_name='yandex.cloud.logging.v1.ListResourcesRequest.log_group_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=64', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='yandex.cloud.logging.v1.ListResourcesRequest.type', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=256', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1849,
  serialized_end=1932,
)


_LISTRESOURCESRESPONSE = _descriptor.Descriptor(
  name='ListResourcesResponse',
  full_name='yandex.cloud.logging.v1.ListResourcesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='resources', full_name='yandex.cloud.logging.v1.ListResourcesResponse.resources', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1934,
  serialized_end=2019,
)


_LISTOPERATIONSREQUEST = _descriptor.Descriptor(
  name='ListOperationsRequest',
  full_name='yandex.cloud.logging.v1.ListOperationsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='log_group_id', full_name='yandex.cloud.logging.v1.ListOperationsRequest.log_group_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=64', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='yandex.cloud.logging.v1.ListOperationsRequest.page_size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\0060-1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='yandex.cloud.logging.v1.ListOperationsRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filter', full_name='yandex.cloud.logging.v1.ListOperationsRequest.filter', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\006<=1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2022,
  serialized_end=2171,
)


_LISTOPERATIONSRESPONSE = _descriptor.Descriptor(
  name='ListOperationsResponse',
  full_name='yandex.cloud.logging.v1.ListOperationsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operations', full_name='yandex.cloud.logging.v1.ListOperationsResponse.operations', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='yandex.cloud.logging.v1.ListOperationsResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2173,
  serialized_end=2277,
)


_GETLOGGROUPSTATSRESPONSE = _descriptor.Descriptor(
  name='GetLogGroupStatsResponse',
  full_name='yandex.cloud.logging.v1.GetLogGroupStatsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='log_group_id', full_name='yandex.cloud.logging.v1.GetLogGroupStatsResponse.log_group_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bytes', full_name='yandex.cloud.logging.v1.GetLogGroupStatsResponse.bytes', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='records', full_name='yandex.cloud.logging.v1.GetLogGroupStatsResponse.records', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2279,
  serialized_end=2359,
)

_LISTLOGGROUPSRESPONSE.fields_by_name['groups'].message_type = yandex_dot_cloud_dot_logging_dot_v1_dot_log__group__pb2._LOGGROUP
_CREATELOGGROUPREQUEST_LABELSENTRY.containing_type = _CREATELOGGROUPREQUEST
_CREATELOGGROUPREQUEST.fields_by_name['labels'].message_type = _CREATELOGGROUPREQUEST_LABELSENTRY
_CREATELOGGROUPREQUEST.fields_by_name['retention_period'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_UPDATELOGGROUPREQUEST_LABELSENTRY.containing_type = _UPDATELOGGROUPREQUEST
_UPDATELOGGROUPREQUEST.fields_by_name['update_mask'].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
_UPDATELOGGROUPREQUEST.fields_by_name['labels'].message_type = _UPDATELOGGROUPREQUEST_LABELSENTRY
_UPDATELOGGROUPREQUEST.fields_by_name['retention_period'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_LISTRESOURCESRESPONSE.fields_by_name['resources'].message_type = yandex_dot_cloud_dot_logging_dot_v1_dot_log__resource__pb2._LOGGROUPRESOURCE
_LISTOPERATIONSRESPONSE.fields_by_name['operations'].message_type = yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION
DESCRIPTOR.message_types_by_name['GetLogGroupRequest'] = _GETLOGGROUPREQUEST
DESCRIPTOR.message_types_by_name['GetLogGroupStatsRequest'] = _GETLOGGROUPSTATSREQUEST
DESCRIPTOR.message_types_by_name['ListLogGroupsRequest'] = _LISTLOGGROUPSREQUEST
DESCRIPTOR.message_types_by_name['ListLogGroupsResponse'] = _LISTLOGGROUPSRESPONSE
DESCRIPTOR.message_types_by_name['CreateLogGroupRequest'] = _CREATELOGGROUPREQUEST
DESCRIPTOR.message_types_by_name['CreateLogGroupMetadata'] = _CREATELOGGROUPMETADATA
DESCRIPTOR.message_types_by_name['UpdateLogGroupRequest'] = _UPDATELOGGROUPREQUEST
DESCRIPTOR.message_types_by_name['UpdateLogGroupMetadata'] = _UPDATELOGGROUPMETADATA
DESCRIPTOR.message_types_by_name['DeleteLogGroupRequest'] = _DELETELOGGROUPREQUEST
DESCRIPTOR.message_types_by_name['DeleteLogGroupMetadata'] = _DELETELOGGROUPMETADATA
DESCRIPTOR.message_types_by_name['ListResourcesRequest'] = _LISTRESOURCESREQUEST
DESCRIPTOR.message_types_by_name['ListResourcesResponse'] = _LISTRESOURCESRESPONSE
DESCRIPTOR.message_types_by_name['ListOperationsRequest'] = _LISTOPERATIONSREQUEST
DESCRIPTOR.message_types_by_name['ListOperationsResponse'] = _LISTOPERATIONSRESPONSE
DESCRIPTOR.message_types_by_name['GetLogGroupStatsResponse'] = _GETLOGGROUPSTATSRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetLogGroupRequest = _reflection.GeneratedProtocolMessageType('GetLogGroupRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETLOGGROUPREQUEST,
  '__module__' : 'yandex.cloud.logging.v1.log_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.logging.v1.GetLogGroupRequest)
  })
_sym_db.RegisterMessage(GetLogGroupRequest)

GetLogGroupStatsRequest = _reflection.GeneratedProtocolMessageType('GetLogGroupStatsRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETLOGGROUPSTATSREQUEST,
  '__module__' : 'yandex.cloud.logging.v1.log_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.logging.v1.GetLogGroupStatsRequest)
  })
_sym_db.RegisterMessage(GetLogGroupStatsRequest)

ListLogGroupsRequest = _reflection.GeneratedProtocolMessageType('ListLogGroupsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTLOGGROUPSREQUEST,
  '__module__' : 'yandex.cloud.logging.v1.log_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.logging.v1.ListLogGroupsRequest)
  })
_sym_db.RegisterMessage(ListLogGroupsRequest)

ListLogGroupsResponse = _reflection.GeneratedProtocolMessageType('ListLogGroupsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTLOGGROUPSRESPONSE,
  '__module__' : 'yandex.cloud.logging.v1.log_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.logging.v1.ListLogGroupsResponse)
  })
_sym_db.RegisterMessage(ListLogGroupsResponse)

CreateLogGroupRequest = _reflection.GeneratedProtocolMessageType('CreateLogGroupRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _CREATELOGGROUPREQUEST_LABELSENTRY,
    '__module__' : 'yandex.cloud.logging.v1.log_group_service_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.logging.v1.CreateLogGroupRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _CREATELOGGROUPREQUEST,
  '__module__' : 'yandex.cloud.logging.v1.log_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.logging.v1.CreateLogGroupRequest)
  })
_sym_db.RegisterMessage(CreateLogGroupRequest)
_sym_db.RegisterMessage(CreateLogGroupRequest.LabelsEntry)

CreateLogGroupMetadata = _reflection.GeneratedProtocolMessageType('CreateLogGroupMetadata', (_message.Message,), {
  'DESCRIPTOR' : _CREATELOGGROUPMETADATA,
  '__module__' : 'yandex.cloud.logging.v1.log_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.logging.v1.CreateLogGroupMetadata)
  })
_sym_db.RegisterMessage(CreateLogGroupMetadata)

UpdateLogGroupRequest = _reflection.GeneratedProtocolMessageType('UpdateLogGroupRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _UPDATELOGGROUPREQUEST_LABELSENTRY,
    '__module__' : 'yandex.cloud.logging.v1.log_group_service_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.logging.v1.UpdateLogGroupRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _UPDATELOGGROUPREQUEST,
  '__module__' : 'yandex.cloud.logging.v1.log_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.logging.v1.UpdateLogGroupRequest)
  })
_sym_db.RegisterMessage(UpdateLogGroupRequest)
_sym_db.RegisterMessage(UpdateLogGroupRequest.LabelsEntry)

UpdateLogGroupMetadata = _reflection.GeneratedProtocolMessageType('UpdateLogGroupMetadata', (_message.Message,), {
  'DESCRIPTOR' : _UPDATELOGGROUPMETADATA,
  '__module__' : 'yandex.cloud.logging.v1.log_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.logging.v1.UpdateLogGroupMetadata)
  })
_sym_db.RegisterMessage(UpdateLogGroupMetadata)

DeleteLogGroupRequest = _reflection.GeneratedProtocolMessageType('DeleteLogGroupRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETELOGGROUPREQUEST,
  '__module__' : 'yandex.cloud.logging.v1.log_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.logging.v1.DeleteLogGroupRequest)
  })
_sym_db.RegisterMessage(DeleteLogGroupRequest)

DeleteLogGroupMetadata = _reflection.GeneratedProtocolMessageType('DeleteLogGroupMetadata', (_message.Message,), {
  'DESCRIPTOR' : _DELETELOGGROUPMETADATA,
  '__module__' : 'yandex.cloud.logging.v1.log_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.logging.v1.DeleteLogGroupMetadata)
  })
_sym_db.RegisterMessage(DeleteLogGroupMetadata)

ListResourcesRequest = _reflection.GeneratedProtocolMessageType('ListResourcesRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTRESOURCESREQUEST,
  '__module__' : 'yandex.cloud.logging.v1.log_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.logging.v1.ListResourcesRequest)
  })
_sym_db.RegisterMessage(ListResourcesRequest)

ListResourcesResponse = _reflection.GeneratedProtocolMessageType('ListResourcesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTRESOURCESRESPONSE,
  '__module__' : 'yandex.cloud.logging.v1.log_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.logging.v1.ListResourcesResponse)
  })
_sym_db.RegisterMessage(ListResourcesResponse)

ListOperationsRequest = _reflection.GeneratedProtocolMessageType('ListOperationsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTOPERATIONSREQUEST,
  '__module__' : 'yandex.cloud.logging.v1.log_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.logging.v1.ListOperationsRequest)
  })
_sym_db.RegisterMessage(ListOperationsRequest)

ListOperationsResponse = _reflection.GeneratedProtocolMessageType('ListOperationsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTOPERATIONSRESPONSE,
  '__module__' : 'yandex.cloud.logging.v1.log_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.logging.v1.ListOperationsResponse)
  })
_sym_db.RegisterMessage(ListOperationsResponse)

GetLogGroupStatsResponse = _reflection.GeneratedProtocolMessageType('GetLogGroupStatsResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETLOGGROUPSTATSRESPONSE,
  '__module__' : 'yandex.cloud.logging.v1.log_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.logging.v1.GetLogGroupStatsResponse)
  })
_sym_db.RegisterMessage(GetLogGroupStatsResponse)


DESCRIPTOR._options = None
_GETLOGGROUPREQUEST.fields_by_name['log_group_id']._options = None
_GETLOGGROUPSTATSREQUEST.fields_by_name['log_group_id']._options = None
_LISTLOGGROUPSREQUEST.fields_by_name['folder_id']._options = None
_LISTLOGGROUPSREQUEST.fields_by_name['page_token']._options = None
_LISTLOGGROUPSREQUEST.fields_by_name['filter']._options = None
_CREATELOGGROUPREQUEST_LABELSENTRY._options = None
_CREATELOGGROUPREQUEST.fields_by_name['folder_id']._options = None
_CREATELOGGROUPREQUEST.fields_by_name['name']._options = None
_CREATELOGGROUPREQUEST.fields_by_name['description']._options = None
_CREATELOGGROUPREQUEST.fields_by_name['labels']._options = None
_CREATELOGGROUPREQUEST.fields_by_name['data_stream']._options = None
_UPDATELOGGROUPREQUEST_LABELSENTRY._options = None
_UPDATELOGGROUPREQUEST.fields_by_name['log_group_id']._options = None
_UPDATELOGGROUPREQUEST.fields_by_name['name']._options = None
_UPDATELOGGROUPREQUEST.fields_by_name['description']._options = None
_UPDATELOGGROUPREQUEST.fields_by_name['labels']._options = None
_UPDATELOGGROUPREQUEST.fields_by_name['data_stream']._options = None
_DELETELOGGROUPREQUEST.fields_by_name['log_group_id']._options = None
_LISTRESOURCESREQUEST.fields_by_name['log_group_id']._options = None
_LISTRESOURCESREQUEST.fields_by_name['type']._options = None
_LISTOPERATIONSREQUEST.fields_by_name['log_group_id']._options = None
_LISTOPERATIONSREQUEST.fields_by_name['page_size']._options = None
_LISTOPERATIONSREQUEST.fields_by_name['page_token']._options = None
_LISTOPERATIONSREQUEST.fields_by_name['filter']._options = None

_LOGGROUPSERVICE = _descriptor.ServiceDescriptor(
  name='LogGroupService',
  full_name='yandex.cloud.logging.v1.LogGroupService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=2362,
  serialized_end=4354,
  methods=[
  _descriptor.MethodDescriptor(
    name='Get',
    full_name='yandex.cloud.logging.v1.LogGroupService.Get',
    index=0,
    containing_service=None,
    input_type=_GETLOGGROUPREQUEST,
    output_type=yandex_dot_cloud_dot_logging_dot_v1_dot_log__group__pb2._LOGGROUP,
    serialized_options=b'\202\323\344\223\002&\022$/logging/v1/logGroups/{log_group_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Stats',
    full_name='yandex.cloud.logging.v1.LogGroupService.Stats',
    index=1,
    containing_service=None,
    input_type=_GETLOGGROUPSTATSREQUEST,
    output_type=_GETLOGGROUPSTATSRESPONSE,
    serialized_options=b'\202\323\344\223\002,\022*/logging/v1/logGroups/{log_group_id}/stats',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='List',
    full_name='yandex.cloud.logging.v1.LogGroupService.List',
    index=2,
    containing_service=None,
    input_type=_LISTLOGGROUPSREQUEST,
    output_type=_LISTLOGGROUPSRESPONSE,
    serialized_options=b'\202\323\344\223\002\027\022\025/logging/v1/logGroups',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Create',
    full_name='yandex.cloud.logging.v1.LogGroupService.Create',
    index=3,
    containing_service=None,
    input_type=_CREATELOGGROUPREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002\032\"\025/logging/v1/logGroups:\001*\262\322*\"\n\026CreateLogGroupMetadata\022\010LogGroup',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Update',
    full_name='yandex.cloud.logging.v1.LogGroupService.Update',
    index=4,
    containing_service=None,
    input_type=_UPDATELOGGROUPREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002)2$/logging/v1/logGroups/{log_group_id}:\001*\262\322*\"\n\026UpdateLogGroupMetadata\022\010LogGroup',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Delete',
    full_name='yandex.cloud.logging.v1.LogGroupService.Delete',
    index=5,
    containing_service=None,
    input_type=_DELETELOGGROUPREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002&*$/logging/v1/logGroups/{log_group_id}\262\322*/\n\026DeleteLogGroupMetadata\022\025google.protobuf.Empty',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListResources',
    full_name='yandex.cloud.logging.v1.LogGroupService.ListResources',
    index=6,
    containing_service=None,
    input_type=_LISTRESOURCESREQUEST,
    output_type=_LISTRESOURCESRESPONSE,
    serialized_options=b'\202\323\344\223\0024\0222/logging/v1/logGroups/{log_group_id}:listResources',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListOperations',
    full_name='yandex.cloud.logging.v1.LogGroupService.ListOperations',
    index=7,
    containing_service=None,
    input_type=_LISTOPERATIONSREQUEST,
    output_type=_LISTOPERATIONSRESPONSE,
    serialized_options=b'\202\323\344\223\0021\022//logging/v1/logGroups/{log_group_id}/operations',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListAccessBindings',
    full_name='yandex.cloud.logging.v1.LogGroupService.ListAccessBindings',
    index=8,
    containing_service=None,
    input_type=yandex_dot_cloud_dot_access_dot_access__pb2._LISTACCESSBINDINGSREQUEST,
    output_type=yandex_dot_cloud_dot_access_dot_access__pb2._LISTACCESSBINDINGSRESPONSE,
    serialized_options=b'\202\323\344\223\0028\0226/logging/v1/logGroups/{resource_id}:listAccessBindings',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetAccessBindings',
    full_name='yandex.cloud.logging.v1.LogGroupService.SetAccessBindings',
    index=9,
    containing_service=None,
    input_type=yandex_dot_cloud_dot_access_dot_access__pb2._SETACCESSBINDINGSREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002:\"5/logging/v1/logGroups/{resource_id}:setAccessBindings:\001*\262\322*9\n access.SetAccessBindingsMetadata\022\025google.protobuf.Empty',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateAccessBindings',
    full_name='yandex.cloud.logging.v1.LogGroupService.UpdateAccessBindings',
    index=10,
    containing_service=None,
    input_type=yandex_dot_cloud_dot_access_dot_access__pb2._UPDATEACCESSBINDINGSREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002=28/logging/v1/logGroups/{resource_id}:updateAccessBindings:\001*\262\322*<\n#access.UpdateAccessBindingsMetadata\022\025google.protobuf.Empty',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_LOGGROUPSERVICE)

DESCRIPTOR.services_by_name['LogGroupService'] = _LOGGROUPSERVICE

# @@protoc_insertion_point(module_scope)
