# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/apploadbalancer/v1/logging.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/apploadbalancer/v1/logging.proto',
  package='yandex.cloud.apploadbalancer.v1',
  syntax='proto3',
  serialized_options=b'\n#yandex.cloud.api.apploadbalancer.v1ZSgithub.com/yandex-cloud/go-genproto/yandex/cloud/apploadbalancer/v1;apploadbalancer',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n-yandex/cloud/apploadbalancer/v1/logging.proto\x12\x1fyandex.cloud.apploadbalancer.v1\x1a\x1dyandex/cloud/validation.proto\"\x8e\x01\n\x0eLogDiscardRule\x12\x1a\n\x05\x63odes\x18\x01 \x03(\x03\x42\x0b\xfa\xc7\x31\x07\x31\x30\x30-599\x12\x44\n\tintervals\x18\x02 \x03(\x0e\x32\x31.yandex.cloud.apploadbalancer.v1.HttpCodeInterval\x12\x1a\n\x07percent\x18\x03 \x01(\x03\x42\t\xfa\xc7\x31\x05\x30-100\"{\n\nLogOptions\x12\x14\n\x0clog_group_id\x18\x01 \x01(\t\x12\x46\n\rdiscard_rules\x18\x02 \x03(\x0b\x32/.yandex.cloud.apploadbalancer.v1.LogDiscardRule\x12\x0f\n\x07\x64isable\x18\x03 \x01(\x08*\xc2\x01\n\x10HttpCodeInterval\x12\"\n\x1eHTTP_CODE_INTERVAL_UNSPECIFIED\x10\x00\x12\x1a\n\x16HTTP_CODE_INTERVAL_1XX\x10\x01\x12\x1a\n\x16HTTP_CODE_INTERVAL_2XX\x10\x02\x12\x1a\n\x16HTTP_CODE_INTERVAL_3XX\x10\x03\x12\x1a\n\x16HTTP_CODE_INTERVAL_4XX\x10\x04\x12\x1a\n\x16HTTP_CODE_INTERVAL_5XX\x10\x05\x42z\n#yandex.cloud.api.apploadbalancer.v1ZSgithub.com/yandex-cloud/go-genproto/yandex/cloud/apploadbalancer/v1;apploadbalancerb\x06proto3'
  ,
  dependencies=[yandex_dot_cloud_dot_validation__pb2.DESCRIPTOR,])

_HTTPCODEINTERVAL = _descriptor.EnumDescriptor(
  name='HttpCodeInterval',
  full_name='yandex.cloud.apploadbalancer.v1.HttpCodeInterval',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='HTTP_CODE_INTERVAL_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HTTP_CODE_INTERVAL_1XX', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HTTP_CODE_INTERVAL_2XX', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HTTP_CODE_INTERVAL_3XX', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HTTP_CODE_INTERVAL_4XX', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HTTP_CODE_INTERVAL_5XX', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=384,
  serialized_end=578,
)
_sym_db.RegisterEnumDescriptor(_HTTPCODEINTERVAL)

HttpCodeInterval = enum_type_wrapper.EnumTypeWrapper(_HTTPCODEINTERVAL)
HTTP_CODE_INTERVAL_UNSPECIFIED = 0
HTTP_CODE_INTERVAL_1XX = 1
HTTP_CODE_INTERVAL_2XX = 2
HTTP_CODE_INTERVAL_3XX = 3
HTTP_CODE_INTERVAL_4XX = 4
HTTP_CODE_INTERVAL_5XX = 5



_LOGDISCARDRULE = _descriptor.Descriptor(
  name='LogDiscardRule',
  full_name='yandex.cloud.apploadbalancer.v1.LogDiscardRule',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='codes', full_name='yandex.cloud.apploadbalancer.v1.LogDiscardRule.codes', index=0,
      number=1, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\007100-599', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='intervals', full_name='yandex.cloud.apploadbalancer.v1.LogDiscardRule.intervals', index=1,
      number=2, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='percent', full_name='yandex.cloud.apploadbalancer.v1.LogDiscardRule.percent', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\0050-100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=114,
  serialized_end=256,
)


_LOGOPTIONS = _descriptor.Descriptor(
  name='LogOptions',
  full_name='yandex.cloud.apploadbalancer.v1.LogOptions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='log_group_id', full_name='yandex.cloud.apploadbalancer.v1.LogOptions.log_group_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='discard_rules', full_name='yandex.cloud.apploadbalancer.v1.LogOptions.discard_rules', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='disable', full_name='yandex.cloud.apploadbalancer.v1.LogOptions.disable', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=258,
  serialized_end=381,
)

_LOGDISCARDRULE.fields_by_name['intervals'].enum_type = _HTTPCODEINTERVAL
_LOGOPTIONS.fields_by_name['discard_rules'].message_type = _LOGDISCARDRULE
DESCRIPTOR.message_types_by_name['LogDiscardRule'] = _LOGDISCARDRULE
DESCRIPTOR.message_types_by_name['LogOptions'] = _LOGOPTIONS
DESCRIPTOR.enum_types_by_name['HttpCodeInterval'] = _HTTPCODEINTERVAL
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

LogDiscardRule = _reflection.GeneratedProtocolMessageType('LogDiscardRule', (_message.Message,), {
  'DESCRIPTOR' : _LOGDISCARDRULE,
  '__module__' : 'yandex.cloud.apploadbalancer.v1.logging_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.apploadbalancer.v1.LogDiscardRule)
  })
_sym_db.RegisterMessage(LogDiscardRule)

LogOptions = _reflection.GeneratedProtocolMessageType('LogOptions', (_message.Message,), {
  'DESCRIPTOR' : _LOGOPTIONS,
  '__module__' : 'yandex.cloud.apploadbalancer.v1.logging_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.apploadbalancer.v1.LogOptions)
  })
_sym_db.RegisterMessage(LogOptions)


DESCRIPTOR._options = None
_LOGDISCARDRULE.fields_by_name['codes']._options = None
_LOGDISCARDRULE.fields_by_name['percent']._options = None
# @@protoc_insertion_point(module_scope)
