# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/mdb/kafka/v1/topic.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from yandex.cloud.mdb.kafka.v1 import common_pb2 as yandex_dot_cloud_dot_mdb_dot_kafka_dot_v1_dot_common__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/mdb/kafka/v1/topic.proto',
  package='yandex.cloud.mdb.kafka.v1',
  syntax='proto3',
  serialized_options=b'\n\035yandex.cloud.api.mdb.kafka.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/kafka/v1;kafka',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n%yandex/cloud/mdb/kafka/v1/topic.proto\x12\x19yandex.cloud.mdb.kafka.v1\x1a\x1egoogle/protobuf/wrappers.proto\x1a&yandex/cloud/mdb/kafka/v1/common.proto\"\xfd\x03\n\x05Topic\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x12\n\ncluster_id\x18\x02 \x01(\t\x12/\n\npartitions\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x37\n\x12replication_factor\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12V\n\x10topic_config_2_1\x18\x05 \x01(\x0b\x32).yandex.cloud.mdb.kafka.v1.TopicConfig2_1H\x00R\x0ftopicConfig_2_1\x12V\n\x10topic_config_2_6\x18\x06 \x01(\x0b\x32).yandex.cloud.mdb.kafka.v1.TopicConfig2_6H\x00R\x0ftopicConfig_2_6\x12V\n\x10topic_config_2_8\x18\x07 \x01(\x0b\x32).yandex.cloud.mdb.kafka.v1.TopicConfig2_8H\x00R\x0ftopicConfig_2_8\x12P\n\x0etopic_config_3\x18\x08 \x01(\x0b\x32\'.yandex.cloud.mdb.kafka.v1.TopicConfig3H\x00R\rtopicConfig_3B\x0e\n\x0ctopic_config\"\xed\x03\n\tTopicSpec\x12\x0c\n\x04name\x18\x01 \x01(\t\x12/\n\npartitions\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x37\n\x12replication_factor\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12V\n\x10topic_config_2_1\x18\x04 \x01(\x0b\x32).yandex.cloud.mdb.kafka.v1.TopicConfig2_1H\x00R\x0ftopicConfig_2_1\x12V\n\x10topic_config_2_6\x18\x05 \x01(\x0b\x32).yandex.cloud.mdb.kafka.v1.TopicConfig2_6H\x00R\x0ftopicConfig_2_6\x12V\n\x10topic_config_2_8\x18\x06 \x01(\x0b\x32).yandex.cloud.mdb.kafka.v1.TopicConfig2_8H\x00R\x0ftopicConfig_2_8\x12P\n\x0etopic_config_3\x18\x07 \x01(\x0b\x32\'.yandex.cloud.mdb.kafka.v1.TopicConfig3H\x00R\rtopicConfig_3B\x0e\n\x0ctopic_config\"\x8c\x07\n\x0eTopicConfig2_1\x12O\n\x0e\x63leanup_policy\x18\x01 \x01(\x0e\x32\x37.yandex.cloud.mdb.kafka.v1.TopicConfig2_1.CleanupPolicy\x12\x44\n\x10\x63ompression_type\x18\x02 \x01(\x0e\x32*.yandex.cloud.mdb.kafka.v1.CompressionType\x12\x38\n\x13\x64\x65lete_retention_ms\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x39\n\x14\x66ile_delete_delay_ms\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x33\n\x0e\x66lush_messages\x18\x05 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12-\n\x08\x66lush_ms\x18\x06 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12:\n\x15min_compaction_lag_ms\x18\x07 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x34\n\x0fretention_bytes\x18\x08 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x31\n\x0cretention_ms\x18\t \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x36\n\x11max_message_bytes\x18\n \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x38\n\x13min_insync_replicas\x18\x0b \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x32\n\rsegment_bytes\x18\x0c \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12/\n\x0bpreallocate\x18\r \x01(\x0b\x32\x1a.google.protobuf.BoolValue\"\x8d\x01\n\rCleanupPolicy\x12\x1e\n\x1a\x43LEANUP_POLICY_UNSPECIFIED\x10\x00\x12\x19\n\x15\x43LEANUP_POLICY_DELETE\x10\x01\x12\x1a\n\x16\x43LEANUP_POLICY_COMPACT\x10\x02\x12%\n!CLEANUP_POLICY_COMPACT_AND_DELETE\x10\x03\"\x8c\x07\n\x0eTopicConfig2_6\x12O\n\x0e\x63leanup_policy\x18\x01 \x01(\x0e\x32\x37.yandex.cloud.mdb.kafka.v1.TopicConfig2_6.CleanupPolicy\x12\x44\n\x10\x63ompression_type\x18\x02 \x01(\x0e\x32*.yandex.cloud.mdb.kafka.v1.CompressionType\x12\x38\n\x13\x64\x65lete_retention_ms\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x39\n\x14\x66ile_delete_delay_ms\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x33\n\x0e\x66lush_messages\x18\x05 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12-\n\x08\x66lush_ms\x18\x06 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12:\n\x15min_compaction_lag_ms\x18\x07 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x34\n\x0fretention_bytes\x18\x08 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x31\n\x0cretention_ms\x18\t \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x36\n\x11max_message_bytes\x18\n \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x38\n\x13min_insync_replicas\x18\x0b \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x32\n\rsegment_bytes\x18\x0c \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12/\n\x0bpreallocate\x18\r \x01(\x0b\x32\x1a.google.protobuf.BoolValue\"\x8d\x01\n\rCleanupPolicy\x12\x1e\n\x1a\x43LEANUP_POLICY_UNSPECIFIED\x10\x00\x12\x19\n\x15\x43LEANUP_POLICY_DELETE\x10\x01\x12\x1a\n\x16\x43LEANUP_POLICY_COMPACT\x10\x02\x12%\n!CLEANUP_POLICY_COMPACT_AND_DELETE\x10\x03\"\x8c\x07\n\x0eTopicConfig2_8\x12O\n\x0e\x63leanup_policy\x18\x01 \x01(\x0e\x32\x37.yandex.cloud.mdb.kafka.v1.TopicConfig2_8.CleanupPolicy\x12\x44\n\x10\x63ompression_type\x18\x02 \x01(\x0e\x32*.yandex.cloud.mdb.kafka.v1.CompressionType\x12\x38\n\x13\x64\x65lete_retention_ms\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x39\n\x14\x66ile_delete_delay_ms\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x33\n\x0e\x66lush_messages\x18\x05 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12-\n\x08\x66lush_ms\x18\x06 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12:\n\x15min_compaction_lag_ms\x18\x07 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x34\n\x0fretention_bytes\x18\x08 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x31\n\x0cretention_ms\x18\t \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x36\n\x11max_message_bytes\x18\n \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x38\n\x13min_insync_replicas\x18\x0b \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x32\n\rsegment_bytes\x18\x0c \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12/\n\x0bpreallocate\x18\r \x01(\x0b\x32\x1a.google.protobuf.BoolValue\"\x8d\x01\n\rCleanupPolicy\x12\x1e\n\x1a\x43LEANUP_POLICY_UNSPECIFIED\x10\x00\x12\x19\n\x15\x43LEANUP_POLICY_DELETE\x10\x01\x12\x1a\n\x16\x43LEANUP_POLICY_COMPACT\x10\x02\x12%\n!CLEANUP_POLICY_COMPACT_AND_DELETE\x10\x03\"\x88\x07\n\x0cTopicConfig3\x12M\n\x0e\x63leanup_policy\x18\x01 \x01(\x0e\x32\x35.yandex.cloud.mdb.kafka.v1.TopicConfig3.CleanupPolicy\x12\x44\n\x10\x63ompression_type\x18\x02 \x01(\x0e\x32*.yandex.cloud.mdb.kafka.v1.CompressionType\x12\x38\n\x13\x64\x65lete_retention_ms\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x39\n\x14\x66ile_delete_delay_ms\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x33\n\x0e\x66lush_messages\x18\x05 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12-\n\x08\x66lush_ms\x18\x06 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12:\n\x15min_compaction_lag_ms\x18\x07 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x34\n\x0fretention_bytes\x18\x08 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x31\n\x0cretention_ms\x18\t \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x36\n\x11max_message_bytes\x18\n \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x38\n\x13min_insync_replicas\x18\x0b \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x32\n\rsegment_bytes\x18\x0c \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12/\n\x0bpreallocate\x18\r \x01(\x0b\x32\x1a.google.protobuf.BoolValue\"\x8d\x01\n\rCleanupPolicy\x12\x1e\n\x1a\x43LEANUP_POLICY_UNSPECIFIED\x10\x00\x12\x19\n\x15\x43LEANUP_POLICY_DELETE\x10\x01\x12\x1a\n\x16\x43LEANUP_POLICY_COMPACT\x10\x02\x12%\n!CLEANUP_POLICY_COMPACT_AND_DELETE\x10\x03\x42\x64\n\x1dyandex.cloud.api.mdb.kafka.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/kafka/v1;kafkab\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,yandex_dot_cloud_dot_mdb_dot_kafka_dot_v1_dot_common__pb2.DESCRIPTOR,])



_TOPICCONFIG2_1_CLEANUPPOLICY = _descriptor.EnumDescriptor(
  name='CleanupPolicy',
  full_name='yandex.cloud.mdb.kafka.v1.TopicConfig2_1.CleanupPolicy',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CLEANUP_POLICY_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CLEANUP_POLICY_DELETE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CLEANUP_POLICY_COMPACT', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CLEANUP_POLICY_COMPACT_AND_DELETE', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1916,
  serialized_end=2057,
)
_sym_db.RegisterEnumDescriptor(_TOPICCONFIG2_1_CLEANUPPOLICY)

_TOPICCONFIG2_6_CLEANUPPOLICY = _descriptor.EnumDescriptor(
  name='CleanupPolicy',
  full_name='yandex.cloud.mdb.kafka.v1.TopicConfig2_6.CleanupPolicy',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CLEANUP_POLICY_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CLEANUP_POLICY_DELETE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CLEANUP_POLICY_COMPACT', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CLEANUP_POLICY_COMPACT_AND_DELETE', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1916,
  serialized_end=2057,
)
_sym_db.RegisterEnumDescriptor(_TOPICCONFIG2_6_CLEANUPPOLICY)

_TOPICCONFIG2_8_CLEANUPPOLICY = _descriptor.EnumDescriptor(
  name='CleanupPolicy',
  full_name='yandex.cloud.mdb.kafka.v1.TopicConfig2_8.CleanupPolicy',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CLEANUP_POLICY_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CLEANUP_POLICY_DELETE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CLEANUP_POLICY_COMPACT', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CLEANUP_POLICY_COMPACT_AND_DELETE', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1916,
  serialized_end=2057,
)
_sym_db.RegisterEnumDescriptor(_TOPICCONFIG2_8_CLEANUPPOLICY)

_TOPICCONFIG3_CLEANUPPOLICY = _descriptor.EnumDescriptor(
  name='CleanupPolicy',
  full_name='yandex.cloud.mdb.kafka.v1.TopicConfig3.CleanupPolicy',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CLEANUP_POLICY_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CLEANUP_POLICY_DELETE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CLEANUP_POLICY_COMPACT', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CLEANUP_POLICY_COMPACT_AND_DELETE', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1916,
  serialized_end=2057,
)
_sym_db.RegisterEnumDescriptor(_TOPICCONFIG3_CLEANUPPOLICY)


_TOPIC = _descriptor.Descriptor(
  name='Topic',
  full_name='yandex.cloud.mdb.kafka.v1.Topic',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.mdb.kafka.v1.Topic.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.mdb.kafka.v1.Topic.cluster_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='partitions', full_name='yandex.cloud.mdb.kafka.v1.Topic.partitions', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='replication_factor', full_name='yandex.cloud.mdb.kafka.v1.Topic.replication_factor', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='topic_config_2_1', full_name='yandex.cloud.mdb.kafka.v1.Topic.topic_config_2_1', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='topicConfig_2_1', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='topic_config_2_6', full_name='yandex.cloud.mdb.kafka.v1.Topic.topic_config_2_6', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='topicConfig_2_6', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='topic_config_2_8', full_name='yandex.cloud.mdb.kafka.v1.Topic.topic_config_2_8', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='topicConfig_2_8', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='topic_config_3', full_name='yandex.cloud.mdb.kafka.v1.Topic.topic_config_3', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='topicConfig_3', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='topic_config', full_name='yandex.cloud.mdb.kafka.v1.Topic.topic_config',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=141,
  serialized_end=650,
)


_TOPICSPEC = _descriptor.Descriptor(
  name='TopicSpec',
  full_name='yandex.cloud.mdb.kafka.v1.TopicSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.mdb.kafka.v1.TopicSpec.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='partitions', full_name='yandex.cloud.mdb.kafka.v1.TopicSpec.partitions', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='replication_factor', full_name='yandex.cloud.mdb.kafka.v1.TopicSpec.replication_factor', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='topic_config_2_1', full_name='yandex.cloud.mdb.kafka.v1.TopicSpec.topic_config_2_1', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='topicConfig_2_1', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='topic_config_2_6', full_name='yandex.cloud.mdb.kafka.v1.TopicSpec.topic_config_2_6', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='topicConfig_2_6', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='topic_config_2_8', full_name='yandex.cloud.mdb.kafka.v1.TopicSpec.topic_config_2_8', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='topicConfig_2_8', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='topic_config_3', full_name='yandex.cloud.mdb.kafka.v1.TopicSpec.topic_config_3', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='topicConfig_3', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='topic_config', full_name='yandex.cloud.mdb.kafka.v1.TopicSpec.topic_config',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=653,
  serialized_end=1146,
)


_TOPICCONFIG2_1 = _descriptor.Descriptor(
  name='TopicConfig2_1',
  full_name='yandex.cloud.mdb.kafka.v1.TopicConfig2_1',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cleanup_policy', full_name='yandex.cloud.mdb.kafka.v1.TopicConfig2_1.cleanup_policy', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='compression_type', full_name='yandex.cloud.mdb.kafka.v1.TopicConfig2_1.compression_type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='delete_retention_ms', full_name='yandex.cloud.mdb.kafka.v1.TopicConfig2_1.delete_retention_ms', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='file_delete_delay_ms', full_name='yandex.cloud.mdb.kafka.v1.TopicConfig2_1.file_delete_delay_ms', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='flush_messages', full_name='yandex.cloud.mdb.kafka.v1.TopicConfig2_1.flush_messages', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='flush_ms', full_name='yandex.cloud.mdb.kafka.v1.TopicConfig2_1.flush_ms', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_compaction_lag_ms', full_name='yandex.cloud.mdb.kafka.v1.TopicConfig2_1.min_compaction_lag_ms', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='retention_bytes', full_name='yandex.cloud.mdb.kafka.v1.TopicConfig2_1.retention_bytes', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='retention_ms', full_name='yandex.cloud.mdb.kafka.v1.TopicConfig2_1.retention_ms', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_message_bytes', full_name='yandex.cloud.mdb.kafka.v1.TopicConfig2_1.max_message_bytes', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_insync_replicas', full_name='yandex.cloud.mdb.kafka.v1.TopicConfig2_1.min_insync_replicas', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='segment_bytes', full_name='yandex.cloud.mdb.kafka.v1.TopicConfig2_1.segment_bytes', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='preallocate', full_name='yandex.cloud.mdb.kafka.v1.TopicConfig2_1.preallocate', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _TOPICCONFIG2_1_CLEANUPPOLICY,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1149,
  serialized_end=2057,
)


_TOPICCONFIG2_6 = _descriptor.Descriptor(
  name='TopicConfig2_6',
  full_name='yandex.cloud.mdb.kafka.v1.TopicConfig2_6',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cleanup_policy', full_name='yandex.cloud.mdb.kafka.v1.TopicConfig2_6.cleanup_policy', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='compression_type', full_name='yandex.cloud.mdb.kafka.v1.TopicConfig2_6.compression_type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='delete_retention_ms', full_name='yandex.cloud.mdb.kafka.v1.TopicConfig2_6.delete_retention_ms', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='file_delete_delay_ms', full_name='yandex.cloud.mdb.kafka.v1.TopicConfig2_6.file_delete_delay_ms', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='flush_messages', full_name='yandex.cloud.mdb.kafka.v1.TopicConfig2_6.flush_messages', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='flush_ms', full_name='yandex.cloud.mdb.kafka.v1.TopicConfig2_6.flush_ms', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_compaction_lag_ms', full_name='yandex.cloud.mdb.kafka.v1.TopicConfig2_6.min_compaction_lag_ms', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='retention_bytes', full_name='yandex.cloud.mdb.kafka.v1.TopicConfig2_6.retention_bytes', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='retention_ms', full_name='yandex.cloud.mdb.kafka.v1.TopicConfig2_6.retention_ms', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_message_bytes', full_name='yandex.cloud.mdb.kafka.v1.TopicConfig2_6.max_message_bytes', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_insync_replicas', full_name='yandex.cloud.mdb.kafka.v1.TopicConfig2_6.min_insync_replicas', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='segment_bytes', full_name='yandex.cloud.mdb.kafka.v1.TopicConfig2_6.segment_bytes', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='preallocate', full_name='yandex.cloud.mdb.kafka.v1.TopicConfig2_6.preallocate', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _TOPICCONFIG2_6_CLEANUPPOLICY,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2060,
  serialized_end=2968,
)


_TOPICCONFIG2_8 = _descriptor.Descriptor(
  name='TopicConfig2_8',
  full_name='yandex.cloud.mdb.kafka.v1.TopicConfig2_8',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cleanup_policy', full_name='yandex.cloud.mdb.kafka.v1.TopicConfig2_8.cleanup_policy', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='compression_type', full_name='yandex.cloud.mdb.kafka.v1.TopicConfig2_8.compression_type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='delete_retention_ms', full_name='yandex.cloud.mdb.kafka.v1.TopicConfig2_8.delete_retention_ms', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='file_delete_delay_ms', full_name='yandex.cloud.mdb.kafka.v1.TopicConfig2_8.file_delete_delay_ms', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='flush_messages', full_name='yandex.cloud.mdb.kafka.v1.TopicConfig2_8.flush_messages', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='flush_ms', full_name='yandex.cloud.mdb.kafka.v1.TopicConfig2_8.flush_ms', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_compaction_lag_ms', full_name='yandex.cloud.mdb.kafka.v1.TopicConfig2_8.min_compaction_lag_ms', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='retention_bytes', full_name='yandex.cloud.mdb.kafka.v1.TopicConfig2_8.retention_bytes', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='retention_ms', full_name='yandex.cloud.mdb.kafka.v1.TopicConfig2_8.retention_ms', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_message_bytes', full_name='yandex.cloud.mdb.kafka.v1.TopicConfig2_8.max_message_bytes', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_insync_replicas', full_name='yandex.cloud.mdb.kafka.v1.TopicConfig2_8.min_insync_replicas', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='segment_bytes', full_name='yandex.cloud.mdb.kafka.v1.TopicConfig2_8.segment_bytes', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='preallocate', full_name='yandex.cloud.mdb.kafka.v1.TopicConfig2_8.preallocate', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _TOPICCONFIG2_8_CLEANUPPOLICY,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2971,
  serialized_end=3879,
)


_TOPICCONFIG3 = _descriptor.Descriptor(
  name='TopicConfig3',
  full_name='yandex.cloud.mdb.kafka.v1.TopicConfig3',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cleanup_policy', full_name='yandex.cloud.mdb.kafka.v1.TopicConfig3.cleanup_policy', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='compression_type', full_name='yandex.cloud.mdb.kafka.v1.TopicConfig3.compression_type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='delete_retention_ms', full_name='yandex.cloud.mdb.kafka.v1.TopicConfig3.delete_retention_ms', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='file_delete_delay_ms', full_name='yandex.cloud.mdb.kafka.v1.TopicConfig3.file_delete_delay_ms', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='flush_messages', full_name='yandex.cloud.mdb.kafka.v1.TopicConfig3.flush_messages', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='flush_ms', full_name='yandex.cloud.mdb.kafka.v1.TopicConfig3.flush_ms', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_compaction_lag_ms', full_name='yandex.cloud.mdb.kafka.v1.TopicConfig3.min_compaction_lag_ms', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='retention_bytes', full_name='yandex.cloud.mdb.kafka.v1.TopicConfig3.retention_bytes', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='retention_ms', full_name='yandex.cloud.mdb.kafka.v1.TopicConfig3.retention_ms', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_message_bytes', full_name='yandex.cloud.mdb.kafka.v1.TopicConfig3.max_message_bytes', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_insync_replicas', full_name='yandex.cloud.mdb.kafka.v1.TopicConfig3.min_insync_replicas', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='segment_bytes', full_name='yandex.cloud.mdb.kafka.v1.TopicConfig3.segment_bytes', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='preallocate', full_name='yandex.cloud.mdb.kafka.v1.TopicConfig3.preallocate', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _TOPICCONFIG3_CLEANUPPOLICY,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3882,
  serialized_end=4786,
)

_TOPIC.fields_by_name['partitions'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_TOPIC.fields_by_name['replication_factor'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_TOPIC.fields_by_name['topic_config_2_1'].message_type = _TOPICCONFIG2_1
_TOPIC.fields_by_name['topic_config_2_6'].message_type = _TOPICCONFIG2_6
_TOPIC.fields_by_name['topic_config_2_8'].message_type = _TOPICCONFIG2_8
_TOPIC.fields_by_name['topic_config_3'].message_type = _TOPICCONFIG3
_TOPIC.oneofs_by_name['topic_config'].fields.append(
  _TOPIC.fields_by_name['topic_config_2_1'])
_TOPIC.fields_by_name['topic_config_2_1'].containing_oneof = _TOPIC.oneofs_by_name['topic_config']
_TOPIC.oneofs_by_name['topic_config'].fields.append(
  _TOPIC.fields_by_name['topic_config_2_6'])
_TOPIC.fields_by_name['topic_config_2_6'].containing_oneof = _TOPIC.oneofs_by_name['topic_config']
_TOPIC.oneofs_by_name['topic_config'].fields.append(
  _TOPIC.fields_by_name['topic_config_2_8'])
_TOPIC.fields_by_name['topic_config_2_8'].containing_oneof = _TOPIC.oneofs_by_name['topic_config']
_TOPIC.oneofs_by_name['topic_config'].fields.append(
  _TOPIC.fields_by_name['topic_config_3'])
_TOPIC.fields_by_name['topic_config_3'].containing_oneof = _TOPIC.oneofs_by_name['topic_config']
_TOPICSPEC.fields_by_name['partitions'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_TOPICSPEC.fields_by_name['replication_factor'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_TOPICSPEC.fields_by_name['topic_config_2_1'].message_type = _TOPICCONFIG2_1
_TOPICSPEC.fields_by_name['topic_config_2_6'].message_type = _TOPICCONFIG2_6
_TOPICSPEC.fields_by_name['topic_config_2_8'].message_type = _TOPICCONFIG2_8
_TOPICSPEC.fields_by_name['topic_config_3'].message_type = _TOPICCONFIG3
_TOPICSPEC.oneofs_by_name['topic_config'].fields.append(
  _TOPICSPEC.fields_by_name['topic_config_2_1'])
_TOPICSPEC.fields_by_name['topic_config_2_1'].containing_oneof = _TOPICSPEC.oneofs_by_name['topic_config']
_TOPICSPEC.oneofs_by_name['topic_config'].fields.append(
  _TOPICSPEC.fields_by_name['topic_config_2_6'])
_TOPICSPEC.fields_by_name['topic_config_2_6'].containing_oneof = _TOPICSPEC.oneofs_by_name['topic_config']
_TOPICSPEC.oneofs_by_name['topic_config'].fields.append(
  _TOPICSPEC.fields_by_name['topic_config_2_8'])
_TOPICSPEC.fields_by_name['topic_config_2_8'].containing_oneof = _TOPICSPEC.oneofs_by_name['topic_config']
_TOPICSPEC.oneofs_by_name['topic_config'].fields.append(
  _TOPICSPEC.fields_by_name['topic_config_3'])
_TOPICSPEC.fields_by_name['topic_config_3'].containing_oneof = _TOPICSPEC.oneofs_by_name['topic_config']
_TOPICCONFIG2_1.fields_by_name['cleanup_policy'].enum_type = _TOPICCONFIG2_1_CLEANUPPOLICY
_TOPICCONFIG2_1.fields_by_name['compression_type'].enum_type = yandex_dot_cloud_dot_mdb_dot_kafka_dot_v1_dot_common__pb2._COMPRESSIONTYPE
_TOPICCONFIG2_1.fields_by_name['delete_retention_ms'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_TOPICCONFIG2_1.fields_by_name['file_delete_delay_ms'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_TOPICCONFIG2_1.fields_by_name['flush_messages'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_TOPICCONFIG2_1.fields_by_name['flush_ms'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_TOPICCONFIG2_1.fields_by_name['min_compaction_lag_ms'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_TOPICCONFIG2_1.fields_by_name['retention_bytes'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_TOPICCONFIG2_1.fields_by_name['retention_ms'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_TOPICCONFIG2_1.fields_by_name['max_message_bytes'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_TOPICCONFIG2_1.fields_by_name['min_insync_replicas'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_TOPICCONFIG2_1.fields_by_name['segment_bytes'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_TOPICCONFIG2_1.fields_by_name['preallocate'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_TOPICCONFIG2_1_CLEANUPPOLICY.containing_type = _TOPICCONFIG2_1
_TOPICCONFIG2_6.fields_by_name['cleanup_policy'].enum_type = _TOPICCONFIG2_6_CLEANUPPOLICY
_TOPICCONFIG2_6.fields_by_name['compression_type'].enum_type = yandex_dot_cloud_dot_mdb_dot_kafka_dot_v1_dot_common__pb2._COMPRESSIONTYPE
_TOPICCONFIG2_6.fields_by_name['delete_retention_ms'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_TOPICCONFIG2_6.fields_by_name['file_delete_delay_ms'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_TOPICCONFIG2_6.fields_by_name['flush_messages'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_TOPICCONFIG2_6.fields_by_name['flush_ms'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_TOPICCONFIG2_6.fields_by_name['min_compaction_lag_ms'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_TOPICCONFIG2_6.fields_by_name['retention_bytes'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_TOPICCONFIG2_6.fields_by_name['retention_ms'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_TOPICCONFIG2_6.fields_by_name['max_message_bytes'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_TOPICCONFIG2_6.fields_by_name['min_insync_replicas'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_TOPICCONFIG2_6.fields_by_name['segment_bytes'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_TOPICCONFIG2_6.fields_by_name['preallocate'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_TOPICCONFIG2_6_CLEANUPPOLICY.containing_type = _TOPICCONFIG2_6
_TOPICCONFIG2_8.fields_by_name['cleanup_policy'].enum_type = _TOPICCONFIG2_8_CLEANUPPOLICY
_TOPICCONFIG2_8.fields_by_name['compression_type'].enum_type = yandex_dot_cloud_dot_mdb_dot_kafka_dot_v1_dot_common__pb2._COMPRESSIONTYPE
_TOPICCONFIG2_8.fields_by_name['delete_retention_ms'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_TOPICCONFIG2_8.fields_by_name['file_delete_delay_ms'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_TOPICCONFIG2_8.fields_by_name['flush_messages'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_TOPICCONFIG2_8.fields_by_name['flush_ms'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_TOPICCONFIG2_8.fields_by_name['min_compaction_lag_ms'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_TOPICCONFIG2_8.fields_by_name['retention_bytes'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_TOPICCONFIG2_8.fields_by_name['retention_ms'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_TOPICCONFIG2_8.fields_by_name['max_message_bytes'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_TOPICCONFIG2_8.fields_by_name['min_insync_replicas'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_TOPICCONFIG2_8.fields_by_name['segment_bytes'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_TOPICCONFIG2_8.fields_by_name['preallocate'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_TOPICCONFIG2_8_CLEANUPPOLICY.containing_type = _TOPICCONFIG2_8
_TOPICCONFIG3.fields_by_name['cleanup_policy'].enum_type = _TOPICCONFIG3_CLEANUPPOLICY
_TOPICCONFIG3.fields_by_name['compression_type'].enum_type = yandex_dot_cloud_dot_mdb_dot_kafka_dot_v1_dot_common__pb2._COMPRESSIONTYPE
_TOPICCONFIG3.fields_by_name['delete_retention_ms'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_TOPICCONFIG3.fields_by_name['file_delete_delay_ms'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_TOPICCONFIG3.fields_by_name['flush_messages'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_TOPICCONFIG3.fields_by_name['flush_ms'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_TOPICCONFIG3.fields_by_name['min_compaction_lag_ms'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_TOPICCONFIG3.fields_by_name['retention_bytes'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_TOPICCONFIG3.fields_by_name['retention_ms'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_TOPICCONFIG3.fields_by_name['max_message_bytes'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_TOPICCONFIG3.fields_by_name['min_insync_replicas'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_TOPICCONFIG3.fields_by_name['segment_bytes'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_TOPICCONFIG3.fields_by_name['preallocate'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_TOPICCONFIG3_CLEANUPPOLICY.containing_type = _TOPICCONFIG3
DESCRIPTOR.message_types_by_name['Topic'] = _TOPIC
DESCRIPTOR.message_types_by_name['TopicSpec'] = _TOPICSPEC
DESCRIPTOR.message_types_by_name['TopicConfig2_1'] = _TOPICCONFIG2_1
DESCRIPTOR.message_types_by_name['TopicConfig2_6'] = _TOPICCONFIG2_6
DESCRIPTOR.message_types_by_name['TopicConfig2_8'] = _TOPICCONFIG2_8
DESCRIPTOR.message_types_by_name['TopicConfig3'] = _TOPICCONFIG3
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Topic = _reflection.GeneratedProtocolMessageType('Topic', (_message.Message,), {
  'DESCRIPTOR' : _TOPIC,
  '__module__' : 'yandex.cloud.mdb.kafka.v1.topic_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.kafka.v1.Topic)
  })
_sym_db.RegisterMessage(Topic)

TopicSpec = _reflection.GeneratedProtocolMessageType('TopicSpec', (_message.Message,), {
  'DESCRIPTOR' : _TOPICSPEC,
  '__module__' : 'yandex.cloud.mdb.kafka.v1.topic_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.kafka.v1.TopicSpec)
  })
_sym_db.RegisterMessage(TopicSpec)

TopicConfig2_1 = _reflection.GeneratedProtocolMessageType('TopicConfig2_1', (_message.Message,), {
  'DESCRIPTOR' : _TOPICCONFIG2_1,
  '__module__' : 'yandex.cloud.mdb.kafka.v1.topic_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.kafka.v1.TopicConfig2_1)
  })
_sym_db.RegisterMessage(TopicConfig2_1)

TopicConfig2_6 = _reflection.GeneratedProtocolMessageType('TopicConfig2_6', (_message.Message,), {
  'DESCRIPTOR' : _TOPICCONFIG2_6,
  '__module__' : 'yandex.cloud.mdb.kafka.v1.topic_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.kafka.v1.TopicConfig2_6)
  })
_sym_db.RegisterMessage(TopicConfig2_6)

TopicConfig2_8 = _reflection.GeneratedProtocolMessageType('TopicConfig2_8', (_message.Message,), {
  'DESCRIPTOR' : _TOPICCONFIG2_8,
  '__module__' : 'yandex.cloud.mdb.kafka.v1.topic_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.kafka.v1.TopicConfig2_8)
  })
_sym_db.RegisterMessage(TopicConfig2_8)

TopicConfig3 = _reflection.GeneratedProtocolMessageType('TopicConfig3', (_message.Message,), {
  'DESCRIPTOR' : _TOPICCONFIG3,
  '__module__' : 'yandex.cloud.mdb.kafka.v1.topic_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.kafka.v1.TopicConfig3)
  })
_sym_db.RegisterMessage(TopicConfig3)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
