# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/ai/stt/v3/stt_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud.ai.stt.v3 import stt_pb2 as yandex_dot_cloud_dot_ai_dot_stt_dot_v3_dot_stt__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/ai/stt/v3/stt_service.proto',
  package='speechkit.stt.v3',
  syntax='proto3',
  serialized_options=b'\n\032yandex.cloud.api.ai.stt.v3Z>github.com/yandex-cloud/go-genproto/yandex/cloud/ai/stt/v3;stt',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n(yandex/cloud/ai/stt/v3/stt_service.proto\x12\x10speechkit.stt.v3\x1a yandex/cloud/ai/stt/v3/stt.proto2q\n\nRecognizer\x12\x63\n\x12RecognizeStreaming\x12\".speechkit.stt.v3.StreamingRequest\x1a#.speechkit.stt.v3.StreamingResponse\"\x00(\x01\x30\x01\x42\\\n\x1ayandex.cloud.api.ai.stt.v3Z>github.com/yandex-cloud/go-genproto/yandex/cloud/ai/stt/v3;sttb\x06proto3'
  ,
  dependencies=[yandex_dot_cloud_dot_ai_dot_stt_dot_v3_dot_stt__pb2.DESCRIPTOR,])



_sym_db.RegisterFileDescriptor(DESCRIPTOR)


DESCRIPTOR._options = None

_RECOGNIZER = _descriptor.ServiceDescriptor(
  name='Recognizer',
  full_name='speechkit.stt.v3.Recognizer',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=96,
  serialized_end=209,
  methods=[
  _descriptor.MethodDescriptor(
    name='RecognizeStreaming',
    full_name='speechkit.stt.v3.Recognizer.RecognizeStreaming',
    index=0,
    containing_service=None,
    input_type=yandex_dot_cloud_dot_ai_dot_stt_dot_v3_dot_stt__pb2._STREAMINGREQUEST,
    output_type=yandex_dot_cloud_dot_ai_dot_stt_dot_v3_dot_stt__pb2._STREAMINGRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_RECOGNIZER)

DESCRIPTOR.services_by_name['Recognizer'] = _RECOGNIZER

# @@protoc_insertion_point(module_scope)
