# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/containerregistry/v1/scanner.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/containerregistry/v1/scanner.proto',
  package='yandex.cloud.containerregistry.v1',
  syntax='proto3',
  serialized_options=b'\n%yandex.cloud.api.containerregistry.v1ZWgithub.com/yandex-cloud/go-genproto/yandex/cloud/containerregistry/v1;containerregistry',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n/yandex/cloud/containerregistry/v1/scanner.proto\x12!yandex.cloud.containerregistry.v1\x1a\x1dyandex/cloud/validation.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xb5\x02\n\nScanResult\x12\n\n\x02id\x18\x01 \x01(\t\x12\x10\n\x08image_id\x18\x02 \x01(\t\x12.\n\nscanned_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x44\n\x06status\x18\x04 \x01(\x0e\x32\x34.yandex.cloud.containerregistry.v1.ScanResult.Status\x12N\n\x0fvulnerabilities\x18\x05 \x01(\x0b\x32\x35.yandex.cloud.containerregistry.v1.VulnerabilityStats\"C\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x0b\n\x07RUNNING\x10\x01\x12\t\n\x05READY\x10\x02\x12\t\n\x05\x45RROR\x10\x03\"x\n\x12VulnerabilityStats\x12\x10\n\x08\x63ritical\x18\x01 \x01(\x03\x12\x0c\n\x04high\x18\x02 \x01(\x03\x12\x0e\n\x06medium\x18\x03 \x01(\x03\x12\x0b\n\x03low\x18\x04 \x01(\x03\x12\x12\n\nnegligible\x18\x05 \x01(\x03\x12\x11\n\tundefined\x18\x06 \x01(\x03\"\xb1\x02\n\rVulnerability\x12K\n\x08severity\x18\x01 \x01(\x0e\x32\x39.yandex.cloud.containerregistry.v1.Vulnerability.Severity\x12J\n\x07package\x18\x02 \x01(\x0b\x32\x37.yandex.cloud.containerregistry.v1.PackageVulnerabilityH\x00\"p\n\x08Severity\x12\x18\n\x14SEVERITY_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x43RITICAL\x10\x01\x12\x08\n\x04HIGH\x10\x02\x12\n\n\x06MEDIUM\x10\x03\x12\x07\n\x03LOW\x10\x04\x12\x0e\n\nNEGLIGIBLE\x10\x05\x12\r\n\tUNDEFINED\x10\x06\x42\x15\n\rvulnerability\x12\x04\xc0\xc1\x31\x01\"v\n\x14PackageVulnerability\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04link\x18\x02 \x01(\t\x12\x0f\n\x07package\x18\x03 \x01(\t\x12\x0e\n\x06source\x18\x04 \x01(\t\x12\x0f\n\x07version\x18\x05 \x01(\t\x12\x10\n\x08\x66ixed_by\x18\x06 \x01(\tB\x80\x01\n%yandex.cloud.api.containerregistry.v1ZWgithub.com/yandex-cloud/go-genproto/yandex/cloud/containerregistry/v1;containerregistryb\x06proto3'
  ,
  dependencies=[yandex_dot_cloud_dot_validation__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,])



_SCANRESULT_STATUS = _descriptor.EnumDescriptor(
  name='Status',
  full_name='yandex.cloud.containerregistry.v1.ScanResult.Status',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STATUS_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RUNNING', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='READY', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ERROR', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=393,
  serialized_end=460,
)
_sym_db.RegisterEnumDescriptor(_SCANRESULT_STATUS)

_VULNERABILITY_SEVERITY = _descriptor.EnumDescriptor(
  name='Severity',
  full_name='yandex.cloud.containerregistry.v1.Vulnerability.Severity',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SEVERITY_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CRITICAL', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HIGH', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MEDIUM', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LOW', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NEGLIGIBLE', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNDEFINED', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=755,
  serialized_end=867,
)
_sym_db.RegisterEnumDescriptor(_VULNERABILITY_SEVERITY)


_SCANRESULT = _descriptor.Descriptor(
  name='ScanResult',
  full_name='yandex.cloud.containerregistry.v1.ScanResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='yandex.cloud.containerregistry.v1.ScanResult.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='image_id', full_name='yandex.cloud.containerregistry.v1.ScanResult.image_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='scanned_at', full_name='yandex.cloud.containerregistry.v1.ScanResult.scanned_at', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='yandex.cloud.containerregistry.v1.ScanResult.status', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vulnerabilities', full_name='yandex.cloud.containerregistry.v1.ScanResult.vulnerabilities', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _SCANRESULT_STATUS,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=151,
  serialized_end=460,
)


_VULNERABILITYSTATS = _descriptor.Descriptor(
  name='VulnerabilityStats',
  full_name='yandex.cloud.containerregistry.v1.VulnerabilityStats',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='critical', full_name='yandex.cloud.containerregistry.v1.VulnerabilityStats.critical', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='high', full_name='yandex.cloud.containerregistry.v1.VulnerabilityStats.high', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='medium', full_name='yandex.cloud.containerregistry.v1.VulnerabilityStats.medium', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='low', full_name='yandex.cloud.containerregistry.v1.VulnerabilityStats.low', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='negligible', full_name='yandex.cloud.containerregistry.v1.VulnerabilityStats.negligible', index=4,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='undefined', full_name='yandex.cloud.containerregistry.v1.VulnerabilityStats.undefined', index=5,
      number=6, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=462,
  serialized_end=582,
)


_VULNERABILITY = _descriptor.Descriptor(
  name='Vulnerability',
  full_name='yandex.cloud.containerregistry.v1.Vulnerability',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='severity', full_name='yandex.cloud.containerregistry.v1.Vulnerability.severity', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='package', full_name='yandex.cloud.containerregistry.v1.Vulnerability.package', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _VULNERABILITY_SEVERITY,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='vulnerability', full_name='yandex.cloud.containerregistry.v1.Vulnerability.vulnerability',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\300\3011\001'),
  ],
  serialized_start=585,
  serialized_end=890,
)


_PACKAGEVULNERABILITY = _descriptor.Descriptor(
  name='PackageVulnerability',
  full_name='yandex.cloud.containerregistry.v1.PackageVulnerability',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.containerregistry.v1.PackageVulnerability.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='link', full_name='yandex.cloud.containerregistry.v1.PackageVulnerability.link', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='package', full_name='yandex.cloud.containerregistry.v1.PackageVulnerability.package', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='source', full_name='yandex.cloud.containerregistry.v1.PackageVulnerability.source', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version', full_name='yandex.cloud.containerregistry.v1.PackageVulnerability.version', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fixed_by', full_name='yandex.cloud.containerregistry.v1.PackageVulnerability.fixed_by', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=892,
  serialized_end=1010,
)

_SCANRESULT.fields_by_name['scanned_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_SCANRESULT.fields_by_name['status'].enum_type = _SCANRESULT_STATUS
_SCANRESULT.fields_by_name['vulnerabilities'].message_type = _VULNERABILITYSTATS
_SCANRESULT_STATUS.containing_type = _SCANRESULT
_VULNERABILITY.fields_by_name['severity'].enum_type = _VULNERABILITY_SEVERITY
_VULNERABILITY.fields_by_name['package'].message_type = _PACKAGEVULNERABILITY
_VULNERABILITY_SEVERITY.containing_type = _VULNERABILITY
_VULNERABILITY.oneofs_by_name['vulnerability'].fields.append(
  _VULNERABILITY.fields_by_name['package'])
_VULNERABILITY.fields_by_name['package'].containing_oneof = _VULNERABILITY.oneofs_by_name['vulnerability']
DESCRIPTOR.message_types_by_name['ScanResult'] = _SCANRESULT
DESCRIPTOR.message_types_by_name['VulnerabilityStats'] = _VULNERABILITYSTATS
DESCRIPTOR.message_types_by_name['Vulnerability'] = _VULNERABILITY
DESCRIPTOR.message_types_by_name['PackageVulnerability'] = _PACKAGEVULNERABILITY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ScanResult = _reflection.GeneratedProtocolMessageType('ScanResult', (_message.Message,), {
  'DESCRIPTOR' : _SCANRESULT,
  '__module__' : 'yandex.cloud.containerregistry.v1.scanner_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.containerregistry.v1.ScanResult)
  })
_sym_db.RegisterMessage(ScanResult)

VulnerabilityStats = _reflection.GeneratedProtocolMessageType('VulnerabilityStats', (_message.Message,), {
  'DESCRIPTOR' : _VULNERABILITYSTATS,
  '__module__' : 'yandex.cloud.containerregistry.v1.scanner_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.containerregistry.v1.VulnerabilityStats)
  })
_sym_db.RegisterMessage(VulnerabilityStats)

Vulnerability = _reflection.GeneratedProtocolMessageType('Vulnerability', (_message.Message,), {
  'DESCRIPTOR' : _VULNERABILITY,
  '__module__' : 'yandex.cloud.containerregistry.v1.scanner_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.containerregistry.v1.Vulnerability)
  })
_sym_db.RegisterMessage(Vulnerability)

PackageVulnerability = _reflection.GeneratedProtocolMessageType('PackageVulnerability', (_message.Message,), {
  'DESCRIPTOR' : _PACKAGEVULNERABILITY,
  '__module__' : 'yandex.cloud.containerregistry.v1.scanner_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.containerregistry.v1.PackageVulnerability)
  })
_sym_db.RegisterMessage(PackageVulnerability)


DESCRIPTOR._options = None
_VULNERABILITY.oneofs_by_name['vulnerability']._options = None
# @@protoc_insertion_point(module_scope)
