# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/oauth/claims.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/oauth/claims.proto',
  package='yandex.cloud.oauth',
  syntax='proto3',
  serialized_options=b'\n\031yandex.cloud.api.oauth.v1Z<github.com/yandex-cloud/go-genproto/yandex/cloud/oauth;oauth',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1fyandex/cloud/oauth/claims.proto\x12\x12yandex.cloud.oauth\x1a\x1dyandex/cloud/validation.proto\"\x89\x02\n\rSubjectClaims\x12\x19\n\x03sub\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x12\n\ngiven_name\x18\x03 \x01(\t\x12\x13\n\x0b\x66\x61mily_name\x18\x04 \x01(\t\x12\x1a\n\x12preferred_username\x18\x07 \x01(\t\x12\x0f\n\x07picture\x18\t \x01(\t\x12\r\n\x05\x65mail\x18\x0b \x01(\t\x12\x10\n\x08zoneinfo\x18\x0f \x01(\t\x12\x0e\n\x06locale\x18\x10 \x01(\t\x12\x14\n\x0cphone_number\x18\x11 \x01(\t\x12\x32\n\nfederation\x18\x64 \x01(\x0b\x32\x1e.yandex.cloud.oauth.Federation\"4\n\nFederation\x12\x18\n\x02id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x0c\n\x04name\x18\x03 \x01(\tBY\n\x19yandex.cloud.api.oauth.v1Z<github.com/yandex-cloud/go-genproto/yandex/cloud/oauth;oauthb\x06proto3'
  ,
  dependencies=[yandex_dot_cloud_dot_validation__pb2.DESCRIPTOR,])




_SUBJECTCLAIMS = _descriptor.Descriptor(
  name='SubjectClaims',
  full_name='yandex.cloud.oauth.SubjectClaims',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sub', full_name='yandex.cloud.oauth.SubjectClaims.sub', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.oauth.SubjectClaims.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='given_name', full_name='yandex.cloud.oauth.SubjectClaims.given_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='family_name', full_name='yandex.cloud.oauth.SubjectClaims.family_name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='preferred_username', full_name='yandex.cloud.oauth.SubjectClaims.preferred_username', index=4,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='picture', full_name='yandex.cloud.oauth.SubjectClaims.picture', index=5,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='email', full_name='yandex.cloud.oauth.SubjectClaims.email', index=6,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='zoneinfo', full_name='yandex.cloud.oauth.SubjectClaims.zoneinfo', index=7,
      number=15, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='locale', full_name='yandex.cloud.oauth.SubjectClaims.locale', index=8,
      number=16, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='phone_number', full_name='yandex.cloud.oauth.SubjectClaims.phone_number', index=9,
      number=17, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='federation', full_name='yandex.cloud.oauth.SubjectClaims.federation', index=10,
      number=100, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=87,
  serialized_end=352,
)


_FEDERATION = _descriptor.Descriptor(
  name='Federation',
  full_name='yandex.cloud.oauth.Federation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='yandex.cloud.oauth.Federation.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.oauth.Federation.name', index=1,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=354,
  serialized_end=406,
)

_SUBJECTCLAIMS.fields_by_name['federation'].message_type = _FEDERATION
DESCRIPTOR.message_types_by_name['SubjectClaims'] = _SUBJECTCLAIMS
DESCRIPTOR.message_types_by_name['Federation'] = _FEDERATION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SubjectClaims = _reflection.GeneratedProtocolMessageType('SubjectClaims', (_message.Message,), {
  'DESCRIPTOR' : _SUBJECTCLAIMS,
  '__module__' : 'yandex.cloud.oauth.claims_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.oauth.SubjectClaims)
  })
_sym_db.RegisterMessage(SubjectClaims)

Federation = _reflection.GeneratedProtocolMessageType('Federation', (_message.Message,), {
  'DESCRIPTOR' : _FEDERATION,
  '__module__' : 'yandex.cloud.oauth.claims_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.oauth.Federation)
  })
_sym_db.RegisterMessage(Federation)


DESCRIPTOR._options = None
_SUBJECTCLAIMS.fields_by_name['sub']._options = None
_FEDERATION.fields_by_name['id']._options = None
# @@protoc_insertion_point(module_scope)
